%define anolis_release 4

# these are all substituted by autoconf
%define pot_file  libsmbios
%define lang_dom  libsmbios-2.4

Name: libsmbios
Version: 2.4.3
Release: %{anolis_release}%{?dist}
Summary: Libsmbios C/C++ shared libraries

License: GPLv2+ or OSL 2.1
URL: https://github.com/dell/libsmbios
Source0: %{url}/archive/v%{version}/libsmbios-%{version}.tar.gz

BuildRequires: make, gcc-c++, autoconf, automake, pkgconfig
BuildRequires: doxygen, help2man, libtool, strace, valgrind
BuildRequires: gettext, gettext-devel
BuildRequires: cppunit-devel, libxml2-devel, python3-devel

# libsmbios only ever makes sense on intel compatible arches
ExclusiveArch: x86_64 

%description
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

This package provides the C-based libsmbios library, with a C interface.

%package -n python3-smbios
Summary: Python interface to Libsmbios C library
Requires: libsmbios = %{version}-%{release}
Requires: python3
Obsoletes: python-smbios < 2.4.1

%description -n python3-smbios
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

This package provides a Python interface to libsmbios

%package -n smbios-utils
Summary: Meta-package that pulls in all smbios binaries and python scripts
Requires: smbios-utils-bin
Requires: smbios-utils-python

%description -n smbios-utils
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

This is a meta-package that pulls in the binary libsmbios executables as well
as the python executables.

%package -n smbios-utils-bin
Summary: Binary utilities that use libsmbios
Requires: libsmbios = %{version}-%{release}

%description -n smbios-utils-bin
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

Get BIOS information, such as System product name, product id, service tag and
asset tag.

%package -n smbios-utils-python
Summary: Python executables that use libsmbios
Requires: python3-smbios = %{version}-%{release}

%description -n smbios-utils-python
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

Get BIOS information, such as System product name, product id, service tag and
asset tag. Set service and asset tags on Dell machines. Manipulate wireless
cards/bluetooth on Dell laptops. Set BIOS password on select Dell systems.
Update BIOS on select Dell systems. Set LCD brightness on select Dell laptops.

%package -n libsmbios-devel
Summary: Development headers and archives
Requires: libsmbios = %{version}-%{release}

%description -n libsmbios-devel
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

This package contains the headers and .a files necessary to compile new client
programs against libsmbios.

%prep
%autosetup -p1

find . -type d -print -exec chmod -f 755 {} \;
find doc src -type f -print -exec chmod -f 644 {} \;
chmod 755 src/cppunit/*.sh

mkdir _build
echo '../configure "$@"' > _build/configure
chmod +x _build/configure

%build
PACKAGE_VERSION=%{version} ./autogen.sh --no-configure
cd _build
%configure

mkdir -p out/libsmbios_c
make CFLAGS+="%{optflags} -Werror" %{?_smp_mflags} 2>&1 | tee build-%{_arch}.log

echo \%doc _build/build-%{_arch}.log | tee buildlogs.txt

%check
runtest() {
    mkdir _$1$2
    pushd _$1$2
        ../configure
        make -e $1 CFLAGS="$CFLAGS -DDEBUG_OUTPUT_ALL" 2>&1 | tee $1$2.log
        touch -r ../configure.ac $1$2-%{_arch}.log
        make -e $1 2>&1 | tee $1$2.log
    popd
    echo \%doc _$1$2/$1$2-%{_arch}.log >> _build/buildlogs.txt
}

VALGRIND="strace -f" runtest check strace > /dev/null || echo FAILED strace check
runtest valgrind > /dev/null || echo FAILED valgrind check
runtest check > /dev/null || echo FAILED check

%install
cd _build
TOPDIR=..
%make_install
rm -f %{buildroot}/%{_libdir}/lib*.{la,a}
find %{buildroot}/%{_includedir} out/libsmbios_c -exec touch -r $TOPDIR/configure.ac {} \;

mv out/libsmbios_c    out/libsmbios_c-%{_arch}

%py_byte_compile %{python3} %{buildroot}%{python3_sitearch}/

rename %{pot_file}.mo %{lang_dom}.mo $(find %{buildroot}/%{_datadir} -name %{pot_file}.mo)
%find_lang %{lang_dom}

%generate_compatibility_deps

%ldconfig_scriptlets

%files -f _build/%{lang_dom}.lang
%dir %{abidir}
# Only need to include license once here
%license COPYING-GPL COPYING-OSL
%{_libdir}/libsmbios_c.so.*
%{abidir}/libsmbios_c*.dump

%files -n libsmbios-devel -f _build/buildlogs.txt
%license src/bin/getopts_LICENSE.txt src/include/smbios_c/config/boost_LICENSE_1_0_txt
%doc README.md _build/out/libsmbios_c-%{_arch}
%{_includedir}/smbios_c
%{_libdir}/libsmbios_c.so
%{_libdir}/pkgconfig/*.pc

%files -n smbios-utils

%files -n smbios-utils-bin
%license src/bin/getopts_LICENSE.txt src/include/smbios_c/config/boost_LICENSE_1_0_txt
%{_sbindir}/smbios-state-byte-ctl
%{_mandir}/man?/smbios-state-byte-ctl.*
%{_sbindir}/smbios-get-ut-data
%{_mandir}/man?/smbios-get-ut-data.*
%{_sbindir}/smbios-upflag-ctl
%{_mandir}/man?/smbios-upflag-ctl.*
%{_sbindir}/smbios-sys-info-lite
%{_mandir}/man?/smbios-sys-info-lite.*
%{abidir}/smbios-state-byte-ctl-option.list
%{abidir}/smbios-get-ut-data-option.list
%{abidir}/smbios-upflag-ctl-option.list
%{abidir}/smbios-sys-info-lite-option.list

%files -n python3-smbios
%{python3_sitearch}/*

%files -n smbios-utils-python
%license src/bin/getopts_LICENSE.txt src/include/smbios_c/config/boost_LICENSE_1_0_txt
%dir %{_sysconfdir}/libsmbios
%config(noreplace) %{_sysconfdir}/libsmbios/*

# python utilities
%{_sbindir}/smbios-battery-ctl
%{_mandir}/man?/smbios-battery-ctl.*
%{_sbindir}/smbios-sys-info
%{_mandir}/man?/smbios-sys-info.*
%{_sbindir}/smbios-token-ctl
%{_mandir}/man?/smbios-token-ctl.*
%{_sbindir}/smbios-passwd
%{_mandir}/man?/smbios-passwd.*
%{_sbindir}/smbios-wakeup-ctl
%{_mandir}/man?/smbios-wakeup-ctl.*
%{_sbindir}/smbios-wireless-ctl
%{_mandir}/man?/smbios-wireless-ctl.*
%{_sbindir}/smbios-lcd-brightness
%{_mandir}/man?/smbios-lcd-brightness.*
%{_sbindir}/smbios-keyboard-ctl
%{_mandir}/man?/smbios-keyboard-ctl.*
%{_sbindir}/smbios-thermal-ctl
%{_mandir}/man?/smbios-thermal-ctl.*

# data files
%{_datadir}/smbios-utils

%changelog
* Tue Mar 12 2024 Bo Ren <rb01097748@alibaba-inc.com> - 2.4.3-4
- Rebuild with python3.11

* Sat Apr 15 2023 DengXiewei <dengxiewei@linux.alibaba.com> - 2.4.3-3
- optimise spec

* Thu Oct 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.4.3-2
- optimise spec file

* Wed Mar 09 2022 Hongwei Qin <qhw01063182@alibaba-inc.com> - 2.4.3-1
- Update to 2.4.3
- Init for Anolis OS 23
